==> kbfx-trinity_3.5.13.2.orig.tar.xz: kbfx-trinity-3.5.13.2/configdialog/kbfxconfigdlgabout.ui.h <==
/****************************************************************************
** ui.h extension file, included from the uic-generated form implementation.
**
** If you want to add, delete, or rename functions or slots, use
** TQt Designer to update this file, preserving your code.
**
** You should not define a constructor or destructor in this file.
** Instead, write your code in functions called init() and destroy().
** These will automatically be called by the form's constructor and
** destructor.
*****************************************************************************/

void KbfxConfigDlgAbout::init()
{
	KbfxPixmapLabelNookie->installEventFilter ( this );
	KbfxPixmapLabelSiraj->installEventFilter ( this );
	KbfxPixmapLabelNathanael->installEventFilter ( this );
	KbfxPixmapLabelPhobosK->installEventFilter ( this );
	KbfxPixmapLabelEphracis->installEventFilter ( this );
	KbfxPixmapLabelJohnny->installEventFilter ( this );

	KbfxMemberTextNookie = tr2i18n (
	                           "<strong>Name:</strong> Mensur Zahirovic (Nookie)"
	                           "<br><br>"
	                           "<strong>Country:</strong> Sweden"
	                           "<br><br>"
	                           "<strong>KBFX:</strong> co-author, Q/A, system design, web designer, bug hunter, project administror"
	                           "<br><br>"
	                           "<strong>Email:</strong> nookie@mail.kbfx.org" );

	KbfxMemberTextSiraj = tr2i18n (
	                          "<strong>Name:</strong> Siraj Razick"
	                          "<br><br>"
	                          "<strong>Country:</strong> Sri Lanka"
	                          "<br><br>"
	                          "<strong>KBFX:</strong> author, maintainer, developer, project administror"
	                          "<br><br>"
	                          "<strong>Email:</strong> siraj@mail.kbfx.org" );

	KbfxMemberTextNathanael = tr2i18n (
	                              "<strong>Name:</strong> Nathanael Dracor Gogniat"
	                              "<br><br>"
	                              "<strong>Country:</strong> Switzerland"
	                              "<br><br>"
	                              "<strong>KBFX:</strong> project technical writer, documentation manager, co-author"
	                              "<br><br>"
	                              "<strong>Email:</strong> nathanael@mail.kbfx.org" );

	KbfxMemberTextPhobosK = tr2i18n (
	                            "<strong>Name:</strong> PhobosK"
	                            "<br><br>"
	                            "<strong>Country:</strong> Bulgaria"
	                            "<br><br>"
	                            "<strong>KBFX:</strong> package & release manager, Q/A, bug hunter, mandriva packages, project administrator, developer TQt/C++"
	                            "<br><br>"
	                            "<strong>Email:</strong> phobosk@mail.kbfx.org" );

	KbfxMemberTextJohnny = tr2i18n (
	                           "<strong>Name:</strong> Johnny Henry Saenz Acuna (scarebyte)"
	                           "<br><br>"
	                           "<strong>Country:</strong> Peru"
	                           "<br><br>"
	                           "<strong>KBFX:</strong> developer TQt4/C++"
	                           "<br><br>"
	                           "<strong>Email:</strong> saenzac@mail.kbfx.org" );

	KbfxMemberTextEphracis = tr2i18n (
	                          "<strong>Name:</strong> Christoffer Brodd-Reijer (Ephracis)"
	                          "<br><br>"
	                          "<strong>Country:</strong> Sweden"
	                          "<br><br>"
	                          "<strong>KBFX:</strong> library developer for Raptor"
	                          "<br><br>"
	                          "<strong>Email:</strong> ephracis@mail.kbfx.org" );
}

bool KbfxConfigDlgAbout::eventFilter ( TQObject *obj, TQEvent *ev )
{
	TQCursor kbfxCursor;
	kbfxCursor.setShape ( Qt::PointingHandCursor );
	this->setCursor ( ( const TQCursor ) kbfxCursor );

	if ( ev->type() == TQEvent::FocusIn || ev->type() == TQEvent::Enter )
	{
		if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelNookie) )
		{
			KbfxTeamInfo->setText ( KbfxMemberTextNookie );
			KbfxUnmarkAllPixmaps();
			KbfxPixmapLabelNookie->setFrameShape ( TQFrame::WinPanel );
			return TRUE;
		}
		else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelSiraj) )
		{
			KbfxTeamInfo->setText ( KbfxMemberTextSiraj );
			KbfxUnmarkAllPixmaps();
			KbfxPixmapLabelSiraj->setFrameShape ( TQFrame::WinPanel );
			return TRUE;
		}
		else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelNathanael) )
		{
			KbfxTeamInfo->setText ( KbfxMemberTextNathanael );
			KbfxUnmarkAllPixmaps();
			KbfxPixmapLabelNathanael->setFrameShape ( TQFrame::WinPanel );
			return TRUE;
		}
		else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelPhobosK) )
		{
			KbfxTeamInfo->setText ( KbfxMemberTextPhobosK );
			KbfxUnmarkAllPixmaps();
			KbfxPixmapLabelPhobosK->setFrameShape ( TQFrame::WinPanel );
			return TRUE;
		}
		else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelJohnny) )
		{
			KbfxTeamInfo->setText ( KbfxMemberTextJohnny );
			KbfxUnmarkAllPixmaps();
			KbfxPixmapLabelJohnny->setFrameShape ( TQFrame::WinPanel );
			return TRUE;
		}
		else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelEphracis) )
		{
			KbfxTeamInfo->setText ( KbfxMemberTextEphracis );
			KbfxUnmarkAllPixmaps();
			KbfxPixmapLabelEphracis->setFrameShape ( TQFrame::WinPanel );
			return TRUE;
		}
	}

/*
	if ( ev->type() == TQEvent::Leave )
	{
		if(
			obj == KbfxPixmapLabelNookie ||
			obj == KbfxPixmapLabelSiraj ||
			obj == KbfxPixmapLabelNathanael ||
			obj == KbfxPixmapLabelPhobosK ||
			obj == KbfxPixmapLabelEphracis ||
			obj == KbfxPixmapLabelJohnny )
		{
			KbfxTeamInfo->setText("");

			return TRUE;
		}
	}
*/

	return TQWidget::eventFilter ( obj, ev );
//	return FALSE;
}

void KbfxConfigDlgAbout::KbfxUnmarkAllPixmaps()
{
	KbfxPixmapLabelNookie->setFrameShape ( TQFrame::NoFrame );
	KbfxPixmapLabelSiraj->setFrameShape ( TQFrame::NoFrame );
	KbfxPixmapLabelNathanael->setFrameShape ( TQFrame::NoFrame );
	KbfxPixmapLabelPhobosK->setFrameShape ( TQFrame::NoFrame );
	KbfxPixmapLabelEphracis->setFrameShape ( TQFrame::NoFrame );
	KbfxPixmapLabelJohnny->setFrameShape ( TQFrame::NoFrame );
}

==> kbfx-trinity-14.0.6.tar.xz: kbfx-trinity-14.0.6/configdialog/kbfxconfigdlgabout.ui.h <==
/****************************************************************************
** ui.h extension file, included from the uic-generated form implementation.
**
** If you want to add, delete, or rename functions or slots, use
** TQt Designer to update this file, preserving your code.
**
** You should not define a constructor or destructor in this file.
** Instead, write your code in functions called init() and destroy().
** These will automatically be called by the form's constructor and
** destructor.
*****************************************************************************/

void KbfxConfigDlgAbout::init()
{
	KbfxPixmapLabelNookie->installEventFilter ( this );
	KbfxPixmapLabelSiraj->installEventFilter ( this );
	KbfxPixmapLabelNathanael->installEventFilter ( this );
	KbfxPixmapLabelPhobosK->installEventFilter ( this );
	KbfxPixmapLabelEphracis->installEventFilter ( this );
	KbfxPixmapLabelJohnny->installEventFilter ( this );

	KbfxMemberTextNookie = tr2i18n (
	                           "<strong>Name:</strong> Mensur Zahirovic (Nookie)"
	                           "<br><br>"
	                           "<strong>Country:</strong> Sweden"
	                           "<br><br>"
	                           "<strong>KBFX:</strong> co-author, Q/A, system design, web designer, bug hunter, project administror"
	                           "<br><br>"
	                           "<strong>Email:</strong> nookie@mail.kbfx.net" );

	KbfxMemberTextSiraj = tr2i18n (
	                          "<strong>Name:</strong> Siraj Razick"
	                          "<br><br>"
	                          "<strong>Country:</strong> Sri Lanka"
	                          "<br><br>"
	                          "<strong>KBFX:</strong> author, maintainer, developer, project administror"
	                          "<br><br>"
	                          "<strong>Email:</strong> siraj@mail.kbfx.net" );

	KbfxMemberTextNathanael = tr2i18n (
	                              "<strong>Name:</strong> Nathanael Dracor Gogniat"
	                              "<br><br>"
	                              "<strong>Country:</strong> Switzerland"
	                              "<br><br>"
	                              "<strong>KBFX:</strong> project technical writer, documentation manager, co-author"
	                              "<br><br>"
	                              "<strong>Email:</strong> nathanael@mail.kbfx.net" );

	KbfxMemberTextPhobosK = tr2i18n (
	                            "<strong>Name:</strong> PhobosK"
	                            "<br><br>"
	                            "<strong>Country:</strong> Bulgaria"
	                            "<br><br>"
	                            "<strong>KBFX:</strong> package & release manager, Q/A, bug hunter, mandriva packages, project administrator, developer TQt/C++"
	                            "<br><br>"
	                            "<strong>Email:</strong> phobosk@mail.kbfx.net" );

	KbfxMemberTextJohnny = tr2i18n (
	                           "<strong>Name:</strong> Johnny Henry Saenz Acuna (scarebyte)"
	                           "<br><br>"
	                           "<strong>Country:</strong> Peru"
	                           "<br><br>"
	                           "<strong>KBFX:</strong> developer TQt4/C++"
	                           "<br><br>"
	                           "<strong>Email:</strong> saenzac@mail.kbfx.net" );

	KbfxMemberTextEphracis = tr2i18n (
	                          "<strong>Name:</strong> Christoffer Brodd-Reijer (Ephracis)"
	                          "<br><br>"
	                          "<strong>Country:</strong> Sweden"
	                          "<br><br>"
	                          "<strong>KBFX:</strong> library developer for Raptor"
	                          "<br><br>"
	                          "<strong>Email:</strong> ephracis@mail.kbfx.net" );
}

bool KbfxConfigDlgAbout::eventFilter ( TQObject *obj, TQEvent *ev )
{
	TQCursor kbfxCursor;
	kbfxCursor.setShape ( Qt::PointingHandCursor );
	this->setCursor ( ( const TQCursor ) kbfxCursor );

	if ( ev->type() == TQEvent::FocusIn || ev->type() == TQEvent::Enter )
	{
		if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelNookie) )
		{
			KbfxTeamInfo->setText ( KbfxMemberTextNookie );
			KbfxUnmarkAllPixmaps();
			KbfxPixmapLabelNookie->setFrameShape ( TQFrame::WinPanel );
			return TRUE;
		}
		else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelSiraj) )
		{
			KbfxTeamInfo->setText ( KbfxMemberTextSiraj );
			KbfxUnmarkAllPixmaps();
			KbfxPixmapLabelSiraj->setFrameShape ( TQFrame::WinPanel );
			return TRUE;
		}
		else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelNathanael) )
		{
			KbfxTeamInfo->setText ( KbfxMemberTextNathanael );
			KbfxUnmarkAllPixmaps();
			KbfxPixmapLabelNathanael->setFrameShape ( TQFrame::WinPanel );
			return TRUE;
		}
		else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelPhobosK) )
		{
			KbfxTeamInfo->setText ( KbfxMemberTextPhobosK );
			KbfxUnmarkAllPixmaps();
			KbfxPixmapLabelPhobosK->setFrameShape ( TQFrame::WinPanel );
			return TRUE;
		}
		else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelJohnny) )
		{
			KbfxTeamInfo->setText ( KbfxMemberTextJohnny );
			KbfxUnmarkAllPixmaps();
			KbfxPixmapLabelJohnny->setFrameShape ( TQFrame::WinPanel );
			return TRUE;
		}
		else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelEphracis) )
		{
			KbfxTeamInfo->setText ( KbfxMemberTextEphracis );
			KbfxUnmarkAllPixmaps();
			KbfxPixmapLabelEphracis->setFrameShape ( TQFrame::WinPanel );
			return TRUE;
		}
	}

/*
	if ( ev->type() == TQEvent::Leave )
	{
		if(
			obj == KbfxPixmapLabelNookie ||
			obj == KbfxPixmapLabelSiraj ||
			obj == KbfxPixmapLabelNathanael ||
			obj == KbfxPixmapLabelPhobosK ||
			obj == KbfxPixmapLabelEphracis ||
			obj == KbfxPixmapLabelJohnny )
		{
			KbfxTeamInfo->setText("");

			return TRUE;
		}
	}
*/

	return TQWidget::eventFilter ( obj, ev );
//	return FALSE;
}

void KbfxConfigDlgAbout::KbfxUnmarkAllPixmaps()
{
	KbfxPixmapLabelNookie->setFrameShape ( TQFrame::NoFrame );
	KbfxPixmapLabelSiraj->setFrameShape ( TQFrame::NoFrame );
	KbfxPixmapLabelNathanael->setFrameShape ( TQFrame::NoFrame );
	KbfxPixmapLabelPhobosK->setFrameShape ( TQFrame::NoFrame );
	KbfxPixmapLabelEphracis->setFrameShape ( TQFrame::NoFrame );
	KbfxPixmapLabelJohnny->setFrameShape ( TQFrame::NoFrame );
}
